import math

from forex_python.converter import CurrencyRates

c = CurrencyRates()


def local_convertor(currency_list):

    first_input = input('First currency: ').upper()
    while first_input not in currency_list:
        print()
        print('Entered currency is not in currency list\nYou can watch all available currencies in main menu')
        first_input = input('Enter currency again: ').upper()
        print()
    else:
        if first_input == 'RUB':
            print()
            print('You currency is not available at this moment\nUSD will be used\n')
            first_input = 'USD'
        else:
            first_input = first_input
    second_input = input('Second currency: ').upper()
    while second_input not in currency_list:
        print()
        print('Entered currency is not in currency list\nYou can watch all available currencies in main menu')
        second_input = input('Enter currency again: ').upper()
        print()
    else:
        if second_input == 'RUB':
            print()
            print('You currency is not available at this moment\nUSD will be used\n')
            second_input = 'USD'
        else:
            second_input = second_input

    while True:
        amount = input('Amount: ')
        try:
            float(amount)
            break
        except ValueError:
            print('Enter only numbers\n')
    print()

    print('Loading...\n')
    first_currency = str(first_input).upper()
    second_currency = str(second_input).upper()
    first_amount = amount

    second_amount = c.convert(first_currency, second_currency, float(first_amount))
    second_amount = math.floor(second_amount * 100) / 100

    conversion_rate = c.get_rate(first_currency, second_currency)
    conversion_rate = math.floor(conversion_rate * 100) / 100

    print(f'{first_currency}: {first_amount}')
    print(f'{second_currency}: {second_amount}')
    print(f'Conversion rate: {conversion_rate}')



import json
import os
import os.path

# from logic.grouped_data import grouped_final
# from logic.input_data import input_string
# from logic.local_convertor import local_convertor
# from logic.search_by_month_data import search_by_month
# from logic.show_all_delete_string import delete_string
# from logic.terminal_name import set_terminal_title, get_terminal_title
# from logic.text_prompts import mainMessage, helpMessage, creditsMessage, availableCurrencies, currency_list
from FinanceTrackerCLI.logic.grouped_data import grouped_final
from FinanceTrackerCLI.logic.input_data import input_string
from FinanceTrackerCLI.logic.local_convertor import local_convertor
from FinanceTrackerCLI.logic.search_by_month_data import search_by_month
from FinanceTrackerCLI.logic.show_all_delete_string import delete_string
from FinanceTrackerCLI.logic.terminal_name import set_terminal_title, get_terminal_title
from FinanceTrackerCLI.logic.text_prompts import mainMessage, helpMessage, creditsMessage, availableCurrencies, currency_list

new_title = 'Finance tracker'
original_title = get_terminal_title()
set_terminal_title(new_title)

current_dir = os.path.dirname(os.path.abspath(__file__))
file_path = os.path.join(current_dir, "data/FinanceList.json")


def main():
    try:
        with open(file_path, "r") as infile:
            finances_list = json.load(infile)
    except FileNotFoundError:
        print("The 'finances.json' file is not found\nStarting a new finance list!")
        finances_list = []

    def clear():
        os.system('cls' if os.name == 'nt' else 'clear')

    choice = ''
    currency = 'USD'
    while choice not in ['8', 'exit', 'quit', 'q', 'e']:
        print(mainMessage)
        choice = input('Enter index: ')
        match choice:
            case '0' | 'help' | 'h':
                clear()
                print(helpMessage)
            case '1' | 'add' | 'a':
                clear()
                print('Adding new string\n')
                input_string(finances_list, currency)
            case '2' | 'find' | 'f':
                clear()
                if len(finances_list) == 0:
                    print('List is empty!')
                else:
                    print('Looking for existing strings\n')
                    search_by_month(finances_list)
            case '3' | 'all' | 'aa':
                clear()
                if len(finances_list) == 0:
                    print('List is empty!')
                else:
                    delete_string(finances_list)
            case '4' | 'grouped' | 'g':
                clear()
                grouped_final(finances_list, currency_list)
            case '5' | 'currency' | 'cur' | 'cr':
                clear()
                print(availableCurrencies)
            case '6' | 'convertor' | 'conv' | 'c':
                clear()
                print('---------Local currency convertor---------\n')
                local_convertor(currency_list)
            case '7' | 'clear' | 'cl':
                clear()
                clear_question = input('Do you want to clean all data? y/n: ')
                if clear_question == 'y':
                    finances_list.clear()
                    print('Cleared!')
            case '8' | 'exit' | 'quit' | 'q' | 'e':
                clear()
                print('Quiting\n')
            case '9' | 'info' | 'credits' | 'i':
                clear()
                print(creditsMessage)
            case _:
                print('Wrong command\n')
    with open(file_path, "w") as outfile:
        json.dump(finances_list, outfile, indent=4)
    set_terminal_title(original_title)
    print("Program Terminated!\n")


if __name__ == "__main__":
    main()



from datetime import datetime
from decimal import Decimal, ROUND_DOWN
from forex_python.converter import CurrencyRates

c = CurrencyRates()


def group_by_month(finances_list, currency_choice):
    if currency_choice != 'USD':
        print('Loading...\n')
    grouped_data = {}
    for item in finances_list:
        parts = item.split('---')
        date_str, expense_income, value, *rest = parts
        date_parts = date_str.split('-')
        month = datetime.strptime(date_parts[1], "%m").strftime("%B")
        year = date_parts[0]
        month_year = f"{month} {year}"
        description = ''
        value = Decimal(value)
        if expense_income == 'Expense':
            value = -value
        value = c.convert('USD', currency_choice, value)
        value = value.quantize(Decimal('0.00'), rounding=ROUND_DOWN)
        if rest:
            description = '---'.join(rest[1:])
        if month_year not in grouped_data:
            grouped_data[month_year] = []
        grouped_data[month_year].append(
            f"{date_parts[2]}---{expense_income}---{value}---{currency_choice}---{description}")
    return grouped_data


def display_grouped_data(grouped_data):
    overall_sum = Decimal('0.0')
    overall_expense = Decimal('0.0')
    overall_income = Decimal('0.0')
    sorted_months = sorted(grouped_data.keys(), key=lambda x: datetime.strptime(x, "%B %Y"), reverse=False)
    currency = ''
    for month in sorted_months:
        values = grouped_data[month]
        print(f"{month}:")

        for value in values:
            parts = value.split('---')
            date, expense_income, amount, *rest = parts
            currency = rest[0] if rest else currency
            print(f"{date}---{expense_income}---{amount}---{currency}---{rest[1] if len(rest) > 1 else ''}")
            amount = Decimal(amount)
            if expense_income == 'Expense':
                overall_expense += amount
            else:
                overall_income += amount
        sum_value = sum(Decimal(value.split('---')[2]) for value in values)
        print("Sum:", sum_value if sum_value >= Decimal('0') else f"-{abs(sum_value)}", currency)
        overall_sum += sum_value
        print()
    print('Expenses:', abs(overall_expense), currency)
    print("Income:", abs(overall_income), currency)
    print("Total:", overall_sum.quantize(Decimal('0.00'), rounding=ROUND_DOWN), currency)


def grouped_final(finances_list, currency_list):
    if not finances_list:
        print('List is empty!')
        return
    print('Displaying grouped data\nList of all available currencies can be found in the main menu')
    currency_choice = input('Enter currency (Or leave for USD): ').upper()
    print()
    if not currency_choice:
        currency_choice = 'USD'
    while currency_choice not in currency_list:
        print('Entered currency is not in the currency list\nYou can view all available currencies in the main menu\n')
        currency_choice = input('Enter currency again: ').upper()
        print()
    if currency_choice == 'RUB':
        print('Your currency is not available at this moment.\nWill be used USD\n')
        currency_choice = 'USD'
    grouped_data = group_by_month(finances_list, currency_choice)
    display_grouped_data(grouped_data)



from . import grouped_data
from . import input_data
from . import local_convertor
from . import search_by_month_data
from . import show_all_delete_string
from . import terminal_name
from . import text_prompts


# from .grouped_data import grouped_final
# from .input_data import input_string
# from .local_convertor import local_convertor
# from .search_by_month_data import search_by_month
# from .show_all_delete_string import delete_string
# from .terminal_name import set_terminal_title, get_terminal_title
# from .text_prompts import mainMessage, helpMessage, creditsMessage, availableCurrencies, currency_list



from setuptools import setup, find_packages

setup(
    name='FinanceTrackerCLI',
    version='1.3.0.5',
    author='Vladimir Kobranov',
    author_email='josephclturok@gmail.com',
    description='Finance tracker CLI app',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/VladimirKobranov/FinanceTrackerCLI',
    classifiers=[
        'Programming Language :: Python :: 3.11',
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS',
    ],
    packages=find_packages('src'),
    package_dir={'': 'src'},
    python_requires='>=3.11',
    install_requires=[
        'forex-python==1.8',
    ],
)
